"""
kutilities

Provides template utility functions as well as 
generate base template files for use with webdevelopment frameworks
"""

__version__ = "0.1.0"
__author__ = 'Chase Kaleikilo'
__credits__ = 'Kaleiko'

def health_check():
    print("hello world!")
